<?php
/**
 * ###############################################
 *
 * SWIFT Framework
 * _______________________________________________
 *
 * @author         Varun Shoor
 *
 * @package        SWIFT
 * @copyright      Copyright (c) 2001-2012, Kayako
 * @license        http://www.kayako.com/license
 * @link           http://www.kayako.com
 *
 * ###############################################
 */

/**
 * The View Sugar Info Controller
 *
 * @author Rahul Bhattacharya
 */
class Controller_SugarCRMInfo extends Controller_staff
{
	/**
	 * Used for storing the request url
	 *
	 * @access private
	 * @var string
	 *
	 * @author Rahul Bhattacharya
	 */
	private $_url = '';

	/**
	 * Constructor
	 *
	 * @author Rahul Bhattacharya
	 */
	public function __construct()
	{
		parent::__construct();

		$this->Load->Library('CustomField:CustomFieldRendererStaff');
		$this->Load->Library('CustomField:CustomFieldManager');

		$this->Language->Load('staff_ticketsmain');
		$this->Language->Load('staff_ticketsmanage');
	}

	/**
	 * Destructor
	 *
	 * @author Rahul Bhattacharya
	 */
	public function __destruct()
	{
		parent::__destruct();
	}

	/**
	 * Render the SugarCrm Info
	 *
	 * @author Rahul Bhattacharya
	 * @param int $_ticketId Ticket id
	 * @return bool "true" on Success, "false" otherwise
	 * @throws SWIFT_Exception If the Class is not Loaded
	 */
	public function FetchInfo($_ticketId)
	{
		if (!$this->GetIsClassLoaded()) {
			throw new SWIFT_Exception(SWIFT_CLASSNOTLOADED);

			return false;
		}

		$_SWIFT = SWIFT::GetInstance();

		if (!$this->GetIsClassLoaded()) {
			throw new SWIFT_Exception(SWIFT_CLASSNOTLOADED);

			return false;
		}

		$_SWIFT->Database->Query('SELECT email FROM ' . TABLE_PREFIX . 'tickets WHERE ticketid=' . $_ticketId);
		while ($_SWIFT->Database->NextRecord()) {
			$_userEmail      = $this->Database->Record['email'];
		}

		$_userEmail = isset($_userEmail) ? $_userEmail : "";

		$this->View->RenderInfo($_userEmail);

		return true;
	}

	/**
	 * Convert the ticket into lead
	 *
	 * @author Rahul Bhattacharya
	 * @param int $_ticketId Ticket id
	 * @return bool "true" on Success, "false" otherwise
	 * @throws SWIFT_Exception If the Class is not Loaded
	 */
	public function ConvertToLead($_ticketId)
	{
		if (!$this->GetIsClassLoaded()) {
			throw new SWIFT_Exception(__CLASS__ . ':  ' . SWIFT_CLASSNOTLOADED);
		}

		$_SWIFT = SWIFT::GetInstance();

		$this->Load->Library('SugarCRMRestAPI:SugarCRMRestAPIRequest');

		$_sugarcrmUsername = $_SWIFT->Settings->Get('sugarcrm_username');
		$_sugarcrmPassword = $_SWIFT->Settings->Get('sugarcrm_password');
		$_sugarcrmApiurl   = $_SWIFT->Settings->Get('sugarcrm_apiurl');

		$this->Load->Model('TicketToLead:SugarCRMTicketLeadMap');

		$_leadId = $this->SugarCRMTicketLeadMap->GetLeadId($_ticketId);

		if ($_leadId)
		{
			$_userEmail = $this->GetEmailId($_ticketId);

			SWIFT_Loader::LoadModel('Ticket:Ticket', APP_TICKETS);

			// If current ticket id is merged with other tickets
			$_SWIFT_TicketObject = SWIFT_Ticket::GetObjectOnID($_ticketId);

			// Did the object load up?
			if (!$_SWIFT_TicketObject instanceof SWIFT_Ticket || !$_SWIFT_TicketObject->GetIsClassLoaded()) {
				throw new SWIFT_Exception(SWIFT_INVALIDDATA);
			}

			$_sugarcrmSessionResponse = $this->SugarCRMRestAPIRequest->LoginRequest($_sugarcrmUsername, $_sugarcrmPassword, $_sugarcrmApiurl);

			$_message = $this->SugarCRMRestAPIRequest->CreateLead($_SWIFT_TicketObject, $_userEmail, $_sugarcrmSessionResponse, $_sugarcrmApiurl);
		}
		else
		{
			$_message = 'Error : Please try again.';
		}

		SWIFT::Info('Message', $_message);
		$this->Load->Controller('Ticket', 'tickets')->Load->Method('View', $_ticketId);

		return true;
	}

	/**
	 * Fetch Email Id from ticket
	 *
	 * @author Rahul Bhattacharya
	 * @param int $_ticketId Ticket Id
	 * @return string $_userEmail User Email
	 * @throws SWIFT_Exception If the Class is not Loaded
	 */
	public function GetEmailId($_ticketId)
	{
		if (!$this->GetIsClassLoaded()) {
			throw new SWIFT_Exception(__CLASS__ . ':  ' . SWIFT_CLASSNOTLOADED);
		}

		$_SWIFT = SWIFT::GetInstance();

		$_SWIFT->Database->Query('SELECT email FROM ' . TABLE_PREFIX . 'tickets WHERE ticketid=' . $_ticketId);
		while ($_SWIFT->Database->NextRecord()) {
			$_userEmail      = $this->Database->Record['email'];
		}

		return isset($_userEmail) ? $_userEmail : "";
	}
}
